
История изменений
=================

1.2 (2013-12-24)
----------------

* Добавлена поддержка django 1.6 - спасибо Александру Симкину;
* Python 2.5 больше не поддерживается.

1.1 (2013-04-12)
----------------

* На странице FailURL больше не проверяется подпись (т.к. Робокасса ее
  больше не передает) - спасибо @amureki;
* улучшена справка - спасибо @bo858585.

1.0 (2012-03-24)
----------------
* Для работы теперь требуется django >= 1.3;
* добавлена поддержка django 1.4;
* все вьюхи возвращают теперь TemplateResponse;
* миграции переведены на современную версию south;
* запуск тестов через tox;
* небольшие улучшения в README.

0.9.3 (2010-08-05)
------------------
Сообщения с ошибочной подписью не вызывают исключения.

0.9.2 (2010-06-23)
------------------
Добавлена поддержка django 1.2.

0.9.1 (2010-05-10)
------------------
Исправлена работа с дополнительными (пользовательскими) параметрами.

0.9.0 (2010-04-15)
------------------
Первая версия

